@@ -77,21 +77,6 @@ class DiscordpyPDAImplementation(engi.ConversationListImplementation):
         .. todo:: Document this.        
         """
 
-        self._register_events()
-
-    def _register_events(self):
-        """
-        .. todo:: Document this.
-        """
-
-        self.log.info("Registering Discord.py events...")
-        self.log.debug("Registering on_message...")
-        self.client.on_message = self._on_message
-        self.log.debug("Registering on_message_edit...")
-        self.client.on_message_edit = self._on_message_edit
-        self.log.debug("Registering on_message_delete...")
-        self.client.on_message_delete = self._on_message_delete
-
     def _determine_key(self, message: d.Message):
         """
         .. todo:: Document this.
